package net.blumia.pcmdroid.ui

import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import net.blumia.pcmdroid.ui.screen.addserver.AddServerScreen
import net.blumia.pcmdroid.ui.screen.main.MainPlayer
import net.blumia.pcmdroid.ui.screen.settings.SettingsScreen

object MainDestinations {
    const val MAIN_ROUTE = "main"
    const val ADD_SERVER_ROUTE = "add_server"
    const val SETTINGS_ROUTE = "settings"
}

@Composable
fun NavGraph(
    navController: NavHostController = rememberNavController(),
    startDestination: String = MainDestinations.MAIN_ROUTE,
) {
    NavHost(
        navController = navController,
        startDestination = startDestination
    ) {
        composable(MainDestinations.MAIN_ROUTE) {
            MainPlayer(
                addServerActionTriggered = {
                    navController.navigate(MainDestinations.ADD_SERVER_ROUTE)
                },
                settingsActionTriggered = {
                    navController.navigate(MainDestinations.SETTINGS_ROUTE)
                }
            )
        }

        composable(MainDestinations.ADD_SERVER_ROUTE) {
            AddServerScreen(
                onCloseActionTriggered = {
                    navController.navigateUp()
                }
            )
        }

        composable(MainDestinations.SETTINGS_ROUTE) {
            SettingsScreen(
                onBackActionTriggered = {
                    navController.navigateUp()
                }
            )
        }
    }
}